import boto3
import json
import datetime
import os
from creds import cred


AWS_CLI_ENVIRONMENT_VARIABLES = ["AWS_ACCESS_KEY_ID", "AWS_SECRET_ACCESS_KEY",
                                 "AWS_SESSION_TOKEN", "AWS_DEFAULT_REGION"
                                 "AWS_DEFAULT_OUTPUT", "AWS_CA_BUNDLE", 
                                 "AWS_SHARED_CREDENTIALS_FILE", "AWS_CONFIG_FILE"]


def logged_in():
    if cred.Credential.get_current():
        return True
    else:
        return False


def get_access_key_age():
    if logged_in():
        session = boto3.Session()
        credentials = session.get_credentials()
        access_key_id = credentials.access_key
        iam = boto3.client('iam')
        access_keys = iam.list_access_keys()
        days_old = 0

        for access_key_metadata in access_keys["AccessKeyMetadata"]:
            if access_key_metadata["AccessKeyId"] == access_key_id:
                create_date = access_key_metadata["CreateDate"].replace(tzinfo=None)
                current_time = datetime.datetime.utcnow().replace(tzinfo=None)
                time_string = str(current_time - create_date).split(",")[0]
                try:
                    days_old = int(time_string.split(" ")[0])
                except:
                    days_old = 0

        return days_old
    else:
        raise NotLoggedInError()


def get_account_details():
    if logged_in():
        sts = boto3.client("sts")
        iam = boto3.client("iam")
        id = sts.get_caller_identity()
        details = { }
    
        details["account"] = id["Account"]
        details["username"] = id["Arn"].split("/")[1]

        # List account aliases through the pagination interface
        try:
            paginator = iam.get_paginator("list_account_aliases")
            for response in paginator.paginate():
                details["aliases"] = response["AccountAliases"][0]
        except:
            details["aliases"] = "N/A"

        return details
    else:
        raise NotLoggedInError()


def rotate_access_keys():
    if logged_in():
        iam = boto3.client('iam')
        access_keys = iam.list_access_keys()["AccessKeyMetadata"]
        if len(access_keys) <= 1:
            current_access_key = access_keys[0]["AccessKeyId"]
            account_details = get_account_details()
            new_access_key_details = iam.create_access_key(UserName=account_details["username"])
            credential = cred.Credential.get_by_access_key(current_access_key)
            credential.access_key = new_access_key_details["AccessKey"]["AccessKeyId"]
            credential.secret_key = new_access_key_details["AccessKey"]["SecretAccessKey"]
            credential.save()
            iam.delete_access_key(
                UserName=account_details["username"],
                AccessKeyId=current_access_key
            )
            cred.Credential.logout()
            return credential
        else:
            raise TooManyAccessKeysError([
                access_keys[0]["AccessKeyId"],
                access_keys[1]["AccessKeyId"]
            ])
    else:
        raise NotLoggedInError()


def check_environment():
    current_environment_variables = os.environ.keys()
    disallowed_environment_variables = []

    for cev in current_environment_variables:
        if cev in AWS_CLI_ENVIRONMENT_VARIABLES:
            disallowed_environment_variables.append(cev)
    
    if len(disallowed_environment_variables) > 0:
        raise EnvironmentVariableIsSetError(disallowed_environment_variables)


class EnvironmentVariableIsSetError(Exception):
    def __init__(self, variable_names):
        self.variable_names = variable_names
        self.message = "Sorry, aws-creds doesn't run correctly when there are environment variables set, please remove them."

class TooManyAccessKeysError(Exception):
    def __init__(self, access_keys):
        self.access_keys = access_keys
        self.message = "Sorry, you have too many access keys. I can only rotate when there is a free Access Key slot available."


class NotLoggedInError(Exception):
    def __init__(self):
        self.message = "You're not logged in."


import click
import sys
import boto3
import datetime
from creds import cred, util, defaults


@click.command()
@click.option("--profile-name", 
              help="Label given to the profile.",
              prompt="Profile Name")
@click.option("--description", 
              help="Full description of the profile.",
              prompt="Description")
@click.option("--access-key", 
              help="AWS Access Key (generated via IAM).",
              prompt="Access Key")
@click.option("--secret-key", 
              help="AWS Secret Key (generated via IAM).",
              hide_input=True,
              prompt="Secret Key")
@click.option("--region", 
              help="Default AWS Region (see https://docs.aws.amazon.com/general/latest/gr/rande.html#ec2_region).",
              prompt="Default Region",
              default=defaults.DefaultConfiguration().region,
              show_default=True)
@click.option("--output", 
              help="Default Output Format (valid options: text, json, table)",
              prompt="Output Type",
              default=defaults.DefaultConfiguration().output,
              show_default=True)
def add(profile_name, description, access_key, secret_key, region, output):
    """Adds a new credential profile."""
    if profile_name and access_key and secret_key:
        my_credential = cred.Credential(profile_name, description, access_key, secret_key, region, output)
        my_credential.save()
        click.echo("New profile created successfully.")
    else:
        click.echo("Sorry, you didn't enter a value for all the options!")


@click.command()
def ls():
    """Lists all of the saved profiles."""

    click.echo(" ")
    click.echo("Installed AWS Profiles")
    click.echo(" ")

    my_credentials = cred.Credential.get_all()
    echo_credentials(my_credentials)
    click.echo("There are " + str(len(my_credentials)) + " active profiles.")
    click.echo(" ")


@click.command()
def login():
    """
    Sets the user's AWS credentials to the selected profile. It does
    this by doing the following:

    \b
    1. Retrieves the credential information.
    2. Saves the Access Key an Secret Key under the [default] profile in the
       AWS Credential file under '~/.aws/credentials'.
    3. Saves the Region and Output settings under the [default] profile in
       the AWS Config file under '~/.aws/config'.
    4. Saves the label of the current profile under '~/.aws/profile.cred'.
    5. Adds a history item to '~/.aws/login_history.log'.
    6. Checks the age of the Access Keys and advises the user if they need
       to be rotated.
    
    """
    click.echo(" ")
    
    try:
        util.check_environment()
        my_credentials = cred.Credential.get_all()
        echo_credentials(my_credentials)
        selection = click.prompt("Which profile would you like to login to", type=int, prompt_suffix="? ") - 1
        click.echo(" ")
        my_credential = my_credentials[selection]
        my_credential.login()
        click.echo("Successfully logged into '" + my_credential.name + "'.")
        check_credential_age()
        click.echo(" ")
    except util.EnvironmentVariableIsSetError as err:
        click.echo("Sorry, there are environment variables set.")
        click.echo(" ")
        
        for v in err.variable_names:
            click.echo(" - " + v)
        
        click.echo(" ")
        click.echo("Please delete the environment variables and try again.")
        click.echo(" ")
    except click.Abort:
        click.echo(" ")
        click.echo(" ")
        click.echo("Exiting, no selection made.")
        click.echo(" ")


@click.command()
def logout():
    """
    Deletes user's current AWS credentials. It does this by doing 
    the following:

    \b
    1. Deletes the AWS Credential file under '~/.aws/credentials'.
    3. Deletes the AWS Config file under '~/.aws/config'.
    4. Deletes '~/.aws/profile.cred'.
    5. Adds a history item to '~/.aws/login_history.log'.

    N.B. As all the credential/acccount information is actually stored under
    '~/.aws/accounts.json', this has no permanent effect on the user's
    stored credentials.
    
    """
    click.echo(" ")
    cred.Credential.logout()
    click.echo("Logged out successfully.")
    click.echo(" ")


@click.command()
def rm():
    """Deletes the selected profile."""
    try:
        click.echo(" ")
        my_credentials = cred.Credential.get_all()
        echo_credentials(my_credentials)
        selection = click.prompt("Which profile would you like to delete", type=int, prompt_suffix="? ") - 1
        click.echo(" ")
        confirmation = click.prompt("'" + my_credentials[selection].name + "' has been selected for deletion. Are you sure (y/n)", type=str, prompt_suffix="? ").lower()

        if confirmation == "y" or confirmation == "yes":
            my_credentials[selection].remove()
            click.echo("Profile deleted successfully.")
        else:
            click.echo("Deletion not confirmed, not continuing.")
        
        click.echo(" ")
    except click.Abort:
        click.echo(" ")
        click.echo(" ")
        click.echo("Exiting, no selection made.")
        click.echo(" ")


@click.command()
def status():
    """
    
    Prints out information about the credential that is currently
    in use. The information it displays to the user is:

    \b
     - Current Profile (Label).
     - Account Number (of the AWS Account/Tenancy).
     - Account Aliases.
     - Username of the IAM User assigned to the Access Key.
     - Access Key.
    
    """

    my_credential = cred.Credential.get_current()

    if my_credential:
        details = util.get_account_details()
        current_role = my_credential.get_current_role()

        # Here so ui doesn't lag when printing details
        if not current_role:
            access_key_age = str(util.get_access_key_age()) + " day(s)."
        
        click.echo(" ")
        click.echo("Current Profile: " + my_credential.name)
        click.echo("Account Number:  " + details["account"])
        click.echo("Account Aliases: " + details["aliases"])
        if current_role:
            click.echo("Assumed Role Arn: " + current_role)
        else:
            click.echo("Username:        " + details["username"])
            click.echo("Access Key:      " + my_credential.access_key)
            click.echo("Access Key Age:  " + access_key_age)
        click.echo(" ")
    else:
        click.echo(" ")
        click.echo("Not logged in.")
        click.echo(" ")


@click.command()    
def update():
    """Updates the selected profile with the new values."""
    click.echo(" ")
    my_credentials = cred.Credential.get_all()
    echo_credentials(my_credentials)
    try:
        selection = click.prompt("Which profile would you like to update", type=int, prompt_suffix="? ") - 1
        my_credential = my_credentials[selection]

        click.echo("If you have no new value, just press enter.")
        click.echo(" ")

        my_credential.name = click.prompt("New Name", default=my_credential.name, show_default=True, type=str)
        my_credential.description = click.prompt("New Description", default=my_credential.description, show_default=True, type=str)
        my_credential.access_key = click.prompt("New Access Key", default=my_credential.access_key, show_default=True, type=str)
        my_credential.secret_key = click.prompt("New Secret Key [*****]", default=my_credential.secret_key, show_default=False, type=str, hide_input=True)
        my_credential.region = click.prompt("New Region", default=my_credential.region, show_default=True, type=str)
        my_credential.output = click.prompt("New Output Type", default=my_credential.output, show_default=True, type=str)

        click.echo(" ")
        my_credential.save()
        click.echo("Profile saved successfully.")
        click.echo(" ")
    except click.Abort:
        click.echo(" ")
        click.echo(" ")
        click.echo("Exiting, no selection made.")
        click.echo(" ")


@click.command()
def rotate():
    """
        Automatically rotates your access keys. It is recommended
        you do not unless you only use your access key on a single workstation.
    """
    click.echo(" ")

    if util.logged_in():
        try:
            current_credential = cred.Credential.get_current()
            click.echo("Current Access Key is '" + current_credential.access_key + "'.")
            click.echo("Rotating keys.")
            credential = util.rotate_access_keys()
            click.echo("Rotation successful.")
            click.echo("New Access Key is '" + credential.access_key + "'.")
        except util.NotLoggedInError as err:
            click.echo(err.message)
        except util.TooManyAccessKeysError as err:
            click.echo(err.message)
            click.echo("Access Key 1: " + err.access_keys[0])
            click.echo("Access Key 1: " + err.access_keys[1])
        except cred.NoCredentialFoundForAccessKeyError as err:
            click.echo(err.message + " (" + err.access_key + ")")
    else:
        click.echo("Sorry, you're not logged in.")
    
    click.echo(" ")


@click.command(name="get")
def get_defaults():
    """
    Prints out the current default region and output type for the awscli.
    """
    click.echo(" ")

    default_config = defaults.DefaultConfiguration()
    click.echo("Default Output: " + default_config.output)
    click.echo("Default Region: " + default_config.region)

    click.echo(" ")


@click.command(name="set")
@click.option("--output", default=None, help="The default output type (json, text, or table).")
@click.option("--region", default=None, help="The default AWS region you want to use.")
def set_defaults(output, region):
    """
    Allows you to set the default region and output type for the awscli.
    """
    click.echo(" ")

    default_config = defaults.DefaultConfiguration()

    try:
        if output:
            default_config.output = output
        else:
            default_config.output = click.prompt("New Default Output", default=default_config.output, show_default=True, type=str)
        
        if region:
            default_config.region = region
        else:
            default_config.region = click.prompt("New Default Region", default=default_config.region, show_default=True, type=str)

        default_config.save()
        click.echo("New defaults saved successfully.")

        click.echo(" ")
    except click.Abort:
        click.echo(" ")
        click.echo(" ")
        click.echo("Exiting, no selection made or empty input.")
        click.echo(" ")


@click.command(name="add")
def add_role():
    """
        Adds a role (from another account) that can be assumed using the current
        iam credentials.
    """
    my_credential = cred.Credential.get_current()

    if my_credential:
        click.echo(" ")
        role_arn = click.prompt("Assumed Role Arn?", type=str)
        click.echo(" ")
        my_credential.roles.append(role_arn)
        my_credential.save()
    else:
        click.echo(" ")
        click.echo("Not logged in.")
        click.echo(" ")


@click.command(name="assume")
def assume_role():
    """
        Assumes a role (from another account) using current iam credentials.
    """
    my_credential = cred.Credential.get_current()

    if my_credential:
        if my_credential.get_current_role():
            my_credential.unassume_role()            
            click.echo(" ")
            click.echo("Logged out of current role.")
            click.echo(" ")
        
        details = util.get_account_details()
        click.echo(" ")
        click.echo("Current Profile: " + my_credential.name)
        click.echo("Account Number:  " + details["account"])
        click.echo("Account Aliases: " + details["aliases"])
        click.echo("Username:        " + details["username"])
        click.echo(" ")
        echo_roles(my_credential)
        role_arn_key = click.prompt("Which role would you like to assume", type=int, prompt_suffix="? ") - 1
        my_credential.assume_role(my_credential.roles[role_arn_key])
        click.echo("Role assumed successfully.")
        click.echo(" ")
    else:
        click.echo(" ")
        click.echo("Not logged in.")
        click.echo(" ")


@click.command(name="unassume")
def unassume_role():
    """
        Unassumes a role, giving access to the original account.
    """
    my_credential = cred.Credential.get_current()

    if my_credential:
        my_credential.unassume_role()
        click.echo(" ")
        click.echo("Role unassumed.")
        click.echo(" ")
    else:
        click.echo(" ")
        click.echo("Not logged in.")
        click.echo(" ")

@click.command(name="ls")
def list_roles():
    """
        Lists roles available to assume.
    """
    my_credential = cred.Credential.get_current()

    if my_credential:
        click.echo(" ")
        click.echo("Available Roles")
        click.echo(" ")
        echo_roles(my_credential)
        click.echo("There are " + str(len(my_credential.roles)) + " roles.")
        click.echo(" ")
    else:
        click.echo(" ")
        click.echo("Not logged in.")
        click.echo(" ")


@click.command(name="rm")
def remove_role():
    """
        Removes an assumed role from the credential profile permanently.
    """
    my_credential = cred.Credential.get_current()

    if my_credential:
        if my_credential.get_current_role():
            my_credential.unassume_role()            
            click.echo(" ")
            click.echo("Logged out of current role.")

        click.echo(" ")
        echo_roles(my_credential)
        role_arn_key = click.prompt("Which role would you like to assume", type=int, prompt_suffix="? ") - 1
        removed_role = my_credential.roles.pop(role_arn_key)
        my_credential.save()
        click.echo(" ")
        click.echo("Removed '" + removed_role + "'.")
        click.echo("Role removed successfully.")
        click.echo(" ")
    else:
        click.echo(" ")
        click.echo("Not logged in.")
        click.echo(" ")


def echo_roles(my_credentials):
    for i in range(0, len(my_credentials.roles)):
        role_arn = my_credentials.roles[i]
        option_number = str(i + 1).zfill(3)
        click.echo("[" + option_number + "] " + role_arn)
        click.echo(" ")


def echo_credentials(my_credentials):
    for i in range(0, len(my_credentials)):
        my_credential = my_credentials[i]
        option_number = str(i + 1).zfill(3)
        click.echo("[" + option_number + "] " + my_credential.name)
        click.echo("      " + my_credential.description)
        click.echo(" ")


def check_credential_age():
    try:
        days_old = util.get_access_key_age()

        if days_old == 1:
            time_string = "1 day"
        else:
            time_string = str(days_old) + " days"

        if days_old < 50:
            click.echo('\033[92m' + "Your current access key is " + time_string + " old." + '\033[0m')
        elif days_old < 60:
            click.echo('\033[93m' + "Your current access key is " + time_string + " old." + '\033[0m')
        else:
            click.echo('\033[91m' + "Your current access key is " + time_string + " old." + '\033[0m')
            click.echo('\033[91m' + "Please rotate it immediately (reason: older than 60 days)." '\033[0m')
    except Exception as err:
        # util.log_error(str(err), "ui.login()")
        print(err)
        click.echo("Error connecting to your account.")
        click.echo("Please clear any AWS environment variables and try again.")


#!/bin/python3
import sys
import click
from creds import cli, cred


@click.group()
@click.version_option()
def main():
    """
        aws-creds makes it easier to use multiple AWS accounts when you don't have SSO available. 
        You can easily save multiple profiles, and then log into them with an simple set of commands.
    """
    pass


@click.group()
def default():
    """
        Used to set the defaults for output type and region.
    """


@click.group()
def role():
    """
        Used to login using an assumed role.
    """


main.add_command(cli.add)
main.add_command(cli.ls)
main.add_command(cli.rm)
main.add_command(cli.login)
main.add_command(cli.logout)
main.add_command(cli.status)
main.add_command(cli.update)
main.add_command(cli.rotate)
default.add_command(cli.get_defaults)
default.add_command(cli.set_defaults)
main.add_command(default)
role.add_command(cli.add_role)
role.add_command(cli.assume_role)
role.add_command(cli.unassume_role)
role.add_command(cli.list_roles)
role.add_command(cli.remove_role)
main.add_command(role)
cred.Credential.migrate()


import uuid
import os
import json
import datetime


class Credential():
    DEFAULT_CREDENTIAL_DIRECTORY = os.path.expanduser("~/.aws/credential_profiles/")
    OLD_ACCOUNTS_FILE_NAME = os.path.expanduser("~/.aws/accounts.json")
    CURRENT_PROFILE_FILE_NAME = os.path.expanduser("~/.aws/.current_profile")
    AWS_CREDENTIAL_FILE_NAME = os.path.expanduser("~/.aws/credentials")
    AWS_CONFIG_FILE_NAME = os.path.expanduser("~/.aws/config")
    CURRENT_ROLE_FILE_NAME = os.path.expanduser("~/.aws/.current_role")


    def __init__(self, name, description, access_key, secret_key, region, output, roles=[], id=str(uuid.uuid4()), create_date=str(datetime.datetime.utcnow().replace(tzinfo=None)), modified_date=None):
        self.id = id
        self.name = name.upper()
        self.description = description
        self.access_key = access_key
        self.secret_key = secret_key
        self.region = region
        self.output = output
        self.roles = roles
        self.create_date = create_date
        if not modified_date:
            self.modified_date = create_date
        else:
            self.modifed_date = modified_date


    def __lt__(self, other):
        if self.name < other.name:
            return True
        else:
            return False


    def __gt__(self, other):
        if self.name > other.name:
            return True
        else:
            return False


    def to_json(self):
        credential_dictionary = {
            "Id": self.id,
            "Name": self.name,
            "Description": self.description,
            "Credentials": {
                "AccessKey": self.access_key,
                "SecretKey": self.secret_key
            },
            "Options": {
                "Region": self.region,
                "OutputType": self.output
            },
            "Roles": self.roles,
            "CreateDate": self.create_date,
            "ModifiedDate": self.modifed_date
        }

        return json.dumps(credential_dictionary, indent=4)


    @staticmethod
    def from_json(id):
        credential_file_name = Credential.DEFAULT_CREDENTIAL_DIRECTORY + id + "/credential.json"

        if os.path.exists(credential_file_name):
            with open(credential_file_name, "r") as fh:
                existing_credential = json.loads(fh.read())

            # Added for backwards compatibility
            if "Roles" not in existing_credential:
                existing_credential["Roles"] = []
            
            credential = Credential(
                existing_credential["Name"],
                existing_credential["Description"],
                existing_credential["Credentials"]["AccessKey"],
                existing_credential["Credentials"]["SecretKey"],
                existing_credential["Options"]["Region"],
                existing_credential["Options"]["OutputType"],
                existing_credential["Roles"],
                existing_credential["Id"],
                existing_credential["CreateDate"],
                existing_credential["ModifiedDate"]
            )

            return credential
        else:
            raise CredentialNotFoundError(id)


    def save(self):
        credential_file_name = self.get_credential_file_name()
        os.makedirs(self.get_directory(), exist_ok=True)
        self.modifed_date = str(datetime.datetime.utcnow().replace(tzinfo=None))
        serialized_self = self.to_json()

        with open(credential_file_name, "w+") as fh:
            fh.write(serialized_self)


    def create_credential_file(self):
        credential_file_contents = "[default]" + os.linesep
        credential_file_contents += "aws_access_key_id=" + self.access_key + os.linesep
        credential_file_contents += "aws_secret_access_key=" + self.secret_key

        credential_file = open(Credential.AWS_CREDENTIAL_FILE_NAME, "w+")
        credential_file.write(credential_file_contents)
        credential_file.close()


    def create_default_options_file(self):
        options_file_contents = "[default]" + os.linesep
        options_file_contents += "region=" + self.region + os.linesep
        options_file_contents += "output=" + self.output
        options_file = open(Credential.AWS_CONFIG_FILE_NAME, "w+")
        options_file.write(options_file_contents)
        options_file.close()


    def login(self):
        self.create_credential_file()
        self.create_default_options_file()
        current_profile_file_contents = self.id
        current_profile_file = open(Credential.CURRENT_PROFILE_FILE_NAME, "w+")
        current_profile_file.write(current_profile_file_contents)
        current_profile_file.close()
        return True
    

    def assume_role(self, role_arn):
        self.create_default_options_file()

        if role_arn not in self.roles:
            raise RoleNotSavedInCurrentCredentialError(role_arn)

        options_file_contents = os.linesep
        options_file_contents += "role_arn=" + role_arn + os.linesep
        options_file_contents += "source_profile=default"
        options_file = open(Credential.AWS_CONFIG_FILE_NAME, "a")
        options_file.write(options_file_contents)
        options_file.close()

        current_profile_file = open(Credential.CURRENT_ROLE_FILE_NAME, "w+")
        current_profile_file.write(role_arn)
        current_profile_file.close()

        return True


    def get_current_role(self):
        if os.path.exists(Credential.CURRENT_ROLE_FILE_NAME):
            with open(Credential.CURRENT_ROLE_FILE_NAME, "r") as fh:
                current_role_arn = fh.read()

            if current_role_arn in self.roles:
                return current_role_arn
            else:
                self.unassume_role()
        else:
            return None 


    def unassume_role(self):
        self.create_default_options_file()
        os.remove(Credential.CURRENT_ROLE_FILE_NAME)


    def remove(self):
        os.remove(self.get_credential_file_name())
        os.rmdir(self.get_directory())
        self.id = None
        self.name = None
        self.description = None
        self.access_key = None
        self.secret_key = None
        self.region = None
        self.output = None
        self.create_date = None

        return True


    def get_directory(self):
        return Credential.DEFAULT_CREDENTIAL_DIRECTORY + self.id

    def get_credential_file_name(self):
        return self.get_directory() + "/credential.json"


    @staticmethod
    def migrate():
        """
            Run once to migrate file version from < v0.5.0 to new structure.
        """
        if os.path.exists(Credential.OLD_ACCOUNTS_FILE_NAME):
            with open(Credential.OLD_ACCOUNTS_FILE_NAME, "r") as fh:
                old_accounts = json.loads(fh.read())

            os.remove(Credential.OLD_ACCOUNTS_FILE_NAME)

            for old_account in old_accounts:
                new_profile = Credential(
                    old_account["profile"],
                    old_account["description"],
                    old_account["access-key"],
                    old_account["secret-key"],
                    old_account["region"],
                    old_account["output"]
                )
                new_profile.save()


    @staticmethod
    def get_all():
        all_credentials = []
        profiles = os.listdir(Credential.DEFAULT_CREDENTIAL_DIRECTORY)

        for profile in profiles:
            if profile != "defaults":
                all_credentials.append(Credential.from_json(profile))

        all_credentials.sort()
        return all_credentials


    @staticmethod
    def get_by_access_key(access_key):
        all_credentials = Credential.get_all()

        for credential in all_credentials:
            if credential.access_key == access_key:
                return credential
        
        raise(NoCredentialFoundForAccessKeyError(access_key))
    

    @staticmethod
    def logout():
        if os.path.exists(Credential.CURRENT_PROFILE_FILE_NAME):
            os.remove(Credential.CURRENT_PROFILE_FILE_NAME)

        if os.path.exists(Credential.AWS_CREDENTIAL_FILE_NAME):
            os.remove(Credential.AWS_CREDENTIAL_FILE_NAME)

        if os.path.exists(Credential.AWS_CONFIG_FILE_NAME):
            os.remove(Credential.AWS_CONFIG_FILE_NAME)

        return True
    

    @staticmethod
    def get_current():
        if os.path.exists(Credential.CURRENT_PROFILE_FILE_NAME):
            with open(Credential.CURRENT_PROFILE_FILE_NAME, "r") as fh:
                current_profile_id = fh.read()

            my_credential = Credential.from_json(current_profile_id)
            return my_credential
        else:
            return None


class CredentialNotFoundError(Exception):
    def __init__(self, credential_id):
        self.credential_id = credential_id
        self.message = "The credential was not found in the DEFAULT_CREDENTIAL_DIRECTORY."


class NoCredentialFoundForAccessKeyError(Exception):
    def __init__(self, access_key):
        self.access_key = access_key
        self.message = "Sorry there is no saved profile for the current account. Have you saved it?"


class RoleNotSavedInCurrentCredentialError(Exception):
    def __init__(self, role_arn):
        self.role_arn = role_arn
        self.message = "Sorry, you can only assume roles that have been saved into the current credential."


import json
import os


class DefaultConfiguration():
    CONFIG_FILE_NAME = os.path.expanduser("~/.aws/credential_profiles/defaults/defaults.json")
    DEFAULT_DEFAULTS = {
            "output": "json",
            "region": "us-east-1"
        }

    def __init__(self):
        if not os.path.exists(os.path.dirname(DefaultConfiguration.CONFIG_FILE_NAME)):
            os.makedirs(os.path.dirname(DefaultConfiguration.CONFIG_FILE_NAME))

        if not os.path.exists(DefaultConfiguration.CONFIG_FILE_NAME):
            self.output = DefaultConfiguration.DEFAULT_DEFAULTS["output"]
            self.region = DefaultConfiguration.DEFAULT_DEFAULTS["region"]
            self.save()
        else:
            self.load()

    def save(self):
        defaults = {
            "output": self.output,
            "region": self.region
        }

        with open(DefaultConfiguration.CONFIG_FILE_NAME, "w+") as fh:
            fh.write(json.dumps(defaults, indent=4))

    def load(self):
        with open(DefaultConfiguration.CONFIG_FILE_NAME, "r") as fh:
            defaults = json.loads(fh.read())
            self.output = defaults["output"]
            self.region = defaults["region"]



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="aws-creds",
    version="2.0.0",
    author="Adam Hammond",
    author_email="adam@hammo.io",
    description="Easily switch between AWS Credential profiles.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/HammoTime/aws-creds",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Natural Language :: English",
        "Topic :: System :: Systems Administration"
    ],
    entry_points = {
        'console_scripts': [
            'aws-creds=creds.main:main'
        ]
    },
    install_requires = [
        "boto3",
        "click"
    ],
    py_modules = [
        "creds.cli",
        "creds.cred"
    ]
)
